singular_jupyter: Jupyter kernel for Singular
=============================================

Description
-----------

This is a Jupyter kernel for Singular.

License
-------

GPL version 2 or later


Upstream Contact
----------------

-  https://github.com/sebasguts/jupyter_kernel_singular
-  https://pypi.org/project/passagemath-singular-jupyterkernel/
